Struct simdutf8::basic::imp::x86::avx2::Utf8ValidatorImp

source ·
pub struct Utf8ValidatorImp { /* private fields */ }
Low-level implementation of the basic::imp::Utf8Validator trait.

This is implementation requires CPU SIMD features specified by the module it resides in. It is undefined behavior to call it if the required CPU features are not available.